<?php

namespace FM\Controller;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\Fm00002VistoriasService;
use FM\Traits\TResponse;

class Fm00002VistoriasController
{
    use TResponse;

    protected $VistoriasService;

    public function __construct($VistoriasService)
    {
        $this->VistoriasService = $VistoriasService;
    }

    public function getVistoriasListadas(Request $request)
    {
        try {
            $data = $this->VistoriasService->getVistoriasListadas($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getFotosVistorias(Request $request)
    {
        try {
            $data = $this->VistoriasService->getFotosVistorias($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function excluirFotoVistorias(Request $request)
    {
        try {
            $data = $this->VistoriasService->excluirFotoVistorias($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getAtividades(Request $request)
    {
        try {
            $data = $this->VistoriasService->getAtividades($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function anexarImagensVistoria(Request $request)
    {
        try {
            $data = $this->VistoriasService->anexarImagensVistoria($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getCriterios(Request $request)
    {
        try {
            //debugApi(['cheguei nos criterios']);
            $data = $this->VistoriasService->getCriterios($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function salvarCriterios(Request $request)
    {
        try {
            $data = $this->VistoriasService->salvarCriterios($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function finalizarVistoria(Request $request)
    {
        try {
            $data = $this->VistoriasService->finalizarVistoria($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getAprovacoes(Request $request)
    {
        try {
            $data = $this->VistoriasService->getAprovacoes($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function aprovarReport(Request $request)
    {
        try {
            $parametros = $request->getParameters();
            $this->VistoriasService->aprovarReport($parametros);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function getOperadoresFiltrados(Request $request)
    {
        try {
            $parametros = $request->getParameters();
            $data = $this->VistoriasService->getOperadoresFiltrados($parametros);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getOperadoresAprovacoes(Request $request)
    {
        try {
            $parametros = $request->getParameters();
            $data = $this->VistoriasService->getOperadoresAprovacoes($parametros);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function voltarTarefaReportada(Request $request)
    {
        try {
            $parametros = $request->getParameters();
            $this->VistoriasService->voltarTarefaReportada($parametros);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getFotosAprovacao(Request $request)
    {
        try {
            $data = $this->VistoriasService->getFotosAprovacao($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
