<?php

namespace FM\Factory;

use Doctrine\ORM\EntityManager;
use FM\Traits\TQuery;

class Fm00002VistoriasFactory
{

    use TQuery;
    protected $entityManager;
    protected $connection;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager    = $entityManager;
    }

    public function getVistoriasListadas($listaOperadoes, $filtros)
    {
        $sql = "SELECT NRGERENCIAMENTOCHK, NMGERENCIAMENTOCHK, NRLOCALCLIENTE, CDOPERADOR, 
                            IDSITUACAOGERCHK, NRSEQCONTRATO, NRCONTRATOFCT, NMFANTCLIE,
                            DTAGEND, HORAAGEND, NMOPERADOR, NMLOCALCLIENTE, LOCALPAI, NMLOCALPAI, 
                            IDSITUACAOAGEND, SUPERVISOR, NMCHECKLISTAGEND, OBS, DATACOMPLETA, SITUACAO
                    FROM (SELECT GCHK.NRGERENCIAMENTOCHK, GCHK.NMGERENCIAMENTOCHK, GCHK.NRLOCALCLIENTE, GCHK.CDOPERADOR, 
                            GCHK.IDSITUACAOGERCHK, GCHK.NRSEQCONTRATO, CT.NRCONTRATOFCT, C.NMFANTCLIE,
                            TO_CHAR(GCHK.DTHORAAGEND, 'DD/MM') DTAGEND,  TO_CHAR(GCHK.DTHORAAGEND, 'HH24:MI') HORAAGEND,
                            FUNC.NMOPERADOR, LC.NMLOCALCLIENTE, LC.NRLOCALCLIENTEPAI AS LOCALPAI, LCP.NMLOCALCLIENTE AS NMLOCALPAI, 
                            CA.IDSITUACAOAGEND, FUNCOP.NMOPERADOR AS SUPERVISOR, CA.NMCHECKLISTAGEND, MAX(FCM_TAREFAGERCHK.DSOBSTAREFAGERCHK) AS OBS, GCHK.DTHORAAGEND AS DATACOMPLETA,
                            CASE GCHK.IDSITUACAOGERCHK 
                                    WHEN '1' THEN 'Aguardando Vistoria'
                                    WHEN '2' THEN 'Em andamento'
                                    WHEN '3' THEN 'Avaliado'
                            ELSE NULL END AS SITUACAO
                    FROM FCM_GERENCIAMENTOCHK GCHK
                    INNER JOIN FCM_LOCALCLI LC 
                        ON LC.NRLOCALCLIENTE = GCHK.NRLOCALCLIENTE
                    INNER JOIN OPERADOR FUNC 
                        ON FUNC.CDOPERADOR = GCHK.CDOPERADOR
                    INNER JOIN FCM_LOCALCLI LCP 
                        ON LCP.NRLOCALCLIENTE = LC.NRLOCALCLIENTEPAI
                    INNER JOIN FCM_CHECKLISTAGEND CA 
                        ON CA.NRCHECKLISTAGEND = GCHK.NRCHECKLISTAGEND
                    LEFT JOIN FCT_CONTRATO CT
                        ON CT.NRSEQCONTRATO = GCHK.NRSEQCONTRATO
                    LEFT JOIN CLIENTE C
                        ON C.CDCLIENTE = LC.CDCLIENTE
                    INNER JOIN OPERADOR FUNCOP
                        ON FUNCOP.CDOPERADOR = CA.CDOPERADOR
                    INNER JOIN FCM_TAREFAGERCHK
                        ON FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK = GCHK.NRGERENCIAMENTOCHK
                    WHERE GCHK.CDOPERADOR 
                        IN ({$listaOperadoes})" . $filtros . "
                        AND CA.IDSITUACAOAGEND = '4'
                    GROUP BY GCHK.NRGERENCIAMENTOCHK, GCHK.NMGERENCIAMENTOCHK, GCHK.NRLOCALCLIENTE, GCHK.CDOPERADOR, 
                            GCHK.IDSITUACAOGERCHK, GCHK.NRSEQCONTRATO, CT.NRCONTRATOFCT, C.NMFANTCLIE,
                            TO_CHAR(GCHK.DTHORAAGEND, 'DD/MM'),  TO_CHAR(GCHK.DTHORAAGEND, 'HH24:MI'),
                            FUNC.NMOPERADOR, LC.NMLOCALCLIENTE, LC.NRLOCALCLIENTEPAI, LCP.NMLOCALCLIENTE, 
                            CA.IDSITUACAOAGEND, FUNCOP.NMOPERADOR, CA.NMCHECKLISTAGEND, GCHK.DTHORAAGEND) VISTORIAS
                    ORDER BY DATACOMPLETA";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getFotosVistorias($parametros)
    {

        $sql = "SELECT FCM_FOTOTAREFAGERCHK.NRFOTOTAREFAGERCHK, FCM_FOTOTAREFAGERCHK.DSFOTOTAREFAGERCHK, FCM_GERENCIAMENTOCHK.NRGERENCIAMENTOCHK, FCM_GERENCIAMENTOCHK.NMGERENCIAMENTOCHK
                    FROM FCM_FOTOTAREFAGERCHK
                    JOIN FCM_TAREFAGERCHK 
                    ON FCM_TAREFAGERCHK.NRTAREFAGERCHK = FCM_FOTOTAREFAGERCHK.NRTAREFAGERCHK
                    JOIN FCM_GERENCIAMENTOCHK 
                    ON FCM_GERENCIAMENTOCHK.NRGERENCIAMENTOCHK = FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK
                    WHERE FCM_GERENCIAMENTOCHK.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function excluirFotoVistorias($parametros)
    {

        $sql = "DELETE FROM FCM_FOTOTAREFAGERCHK
                    WHERE NRFOTOTAREFAGERCHK = :NRFOTOTAREFAGERCHK";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getAtividades($parametros)
    {

        $sql = "SELECT DISTINCT FCM_ATIVIDADECHK.NRATIVIDADECHK, FCM_ATIVIDADE.NMATIVIDADE
                  FROM FCM_ATIVIDADECHK
                  JOIN FCM_ATIVIDADE
                    ON FCM_ATIVIDADE.NRATIVIDADE = FCM_ATIVIDADECHK.NRATIVIDADE
                  JOIN FCM_TAREFACHK
                    ON FCM_TAREFACHK.NRATIVIDADECHK = FCM_ATIVIDADECHK.NRATIVIDADECHK
                    AND NRTAREFACHK IN (SELECT NRTAREFACHK
                                          FROM FCM_TAREFAGERCHK
                                         WHERE NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK)";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getCodTarefaGerChk($parametros)
    {

        $sql = "SELECT NRTAREFAGERCHK
                    FROM FCM_TAREFAGERCHK
                    WHERE NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function anexarImagemVistorias($parametros)
    {

        $sql = "INSERT INTO FCM_FOTOTAREFAGERCHK (NRFOTOTAREFAGERCHK, NRTAREFAGERCHK, DSFOTOTAREFAGERCHK, IDATIVO, NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, DSTYPE, NRSIZE)
        VALUES (:NRFOTOTAREFAGERCHK, :NRTAREFAGERCHK, :DSFOTOTAREFAGERCHK, 'S', :NRORG, SYSDATE, :CDOPERINCLUSAO, :NRORGINCLUSAO, :DSTYPE, :NRSIZE)";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getCriterios($parametros)
    {

        $sql = "SELECT FCM_CRITERIOTARGERCHK.NRCRITERIOTARGERCHK, FCM_CRITERIOTARGERCHK.NMCRITERIOTARGERCHK, FCM_CRITERIOTARGERCHK.IDMARCADO
                    FROM FCM_CRITERIOTARGERCHK
                    JOIN FCM_TAREFAGERCHK
                    ON FCM_CRITERIOTARGERCHK.NRTAREFAGERCHK = FCM_TAREFAGERCHK.NRTAREFAGERCHK
                    JOIN FCM_TAREFACHK
                    ON FCM_TAREFAGERCHK.NRTAREFACHK = FCM_TAREFACHK.NRTAREFACHK
                    JOIN FCM_TAREFA 
                    ON FCM_TAREFA.NRTAREFA = FCM_TAREFACHK.NRTAREFA
                WHERE FCM_TAREFACHK.NRATIVIDADECHK = :NRATIVIDADECHK
                    AND FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function updateCriterios($parametros, $paramQuery)
    {

        $sql = "UPDATE FCM_CRITERIOTARGERCHK
                    SET IDMARCADO = :IDMARCADO,
                        DTULTATU = SYSDATE,
                        CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU
                  WHERE NRCRITERIOTARGERCHK IN (SELECT NRCRITERIOTARGERCHK
                                                    FROM FCM_CRITERIOTARGERCHK
                                                   WHERE NRTAREFAGERCHK IN (SELECT FCM_TAREFAGERCHK.NRTAREFAGERCHK
                                                    FROM FCM_TAREFAGERCHK
                                                    JOIN FCM_TAREFACHK
                                                      ON FCM_TAREFACHK.NRTAREFACHK = FCM_TAREFAGERCHK.NRTAREFACHK
                                                   WHERE FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK
                                                     AND FCM_TAREFACHK.NRATIVIDADECHK = :NRATIVIDADECHK))" . $paramQuery;

        $this->connection->executeStatement($sql, $parametros);
    }

    public function updateObservacao($parametros)
    {

        $sql = "UPDATE FCM_TAREFAGERCHK
                SET DSOBSTAREFAGERCHK = :DSOBSTAREFAGERCHK,
                    DTULTATU = SYSDATE,
                    CDOPERULTATU = :CDOPERULTATU,
                    NRORGULTATU = :NRORGULTATU
                    WHERE NRTAREFAGERCHK IN (SELECT FCM_TAREFAGERCHK.NRTAREFAGERCHK
                                  FROM FCM_TAREFAGERCHK
                                  JOIN FCM_TAREFACHK
                                    ON FCM_TAREFACHK.NRTAREFACHK = FCM_TAREFAGERCHK.NRTAREFACHK
                                 WHERE FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK
                                   AND FCM_TAREFACHK.NRATIVIDADECHK = :NRATIVIDADECHK)";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function updateStatusVistoria($parametros)
    {

        $sql = "UPDATE FCM_GERENCIAMENTOCHK
                SET IDSITUACAOGERCHK = :IDSITUACAOGERCHK,
                    DTULTATU = SYSDATE,
                    CDOPERULTATU = :CDOPERULTATU,
                    NRORGULTATU = :NRORGULTATU
                  WHERE NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";


        $this->connection->executeStatement($sql, $parametros);
    }

    public function getNomeVistoria($parametros)
    {
        $sql = "SELECT NMGERENCIAMENTOCHK
                FROM FCM_GERENCIAMENTOCHK
                WHERE NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function atualizaHistoricoVistoria($parametros)
    {
        $sql = "INSERT INTO FCM_GERCHKHISTORICO (
                    NRGERCHKHISTORICO,      NRGERENCIAMENTOCHK, NMGERENCIAMENTOCHK, DSGERENCIAMENTOCHK,
                    DTHISTGERENCIAMENTOCHK, IDTIPOHISTORICO,    IDATIVO,            NRORG,
                    DTINCLUSAO,             CDOPERINCLUSAO,     NRORGINCLUSAO,      DTULTATU,
                    CDOPERULTATU,           NRORGULTATU
                )
                VALUES (
                    :NRGERCHKHISTORICO,     :NRGERENCIAMENTOCHK, :NMGERENCIAMENTOCHK, :DSGERENCIAMENTOCHK,
                    SYSDATE,                :IDTIPOHISTORICO,    'S',                 :NRORG,
                    SYSDATE,                :CDOPERINCLUSAO,     :NRORGINCLUSAO,      SYSDATE,
                    :CDOPERULTATU,          :NRORGULTATU
                )";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getTarefaVinculada($parametros)
    {
        $sql = "SELECT CHK.NRCHECKLISTAGEND, CHK.NMCHECKLISTAGEND
                FROM FCM_CHECKLISTAGEND CHK
                JOIN FCM_GERENCIAMENTOCHK GER ON CHK.NRCHECKLISTAGEND = GER.NRCHECKLISTAGEND
                WHERE GER.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function atualizaHistoricoTarefa($parametros)
    {
        $sql = "INSERT INTO FCM_CHKAGENDHISTORICO (
                    NRCHKAGENDHISTORICO,    NRCHECKLISTAGEND,   NMCHECKLISTAGEND,   DSCHKAGENDHISTORICO,
                    DTCHKAGENDHISTORICO,    IDTIPOHISTORICO,    IDATIVO,            NRORG,
                    DTINCLUSAO,             CDOPERINCLUSAO,     NRORGINCLUSAO,      DTULTATU,
                    CDOPERULTATU,           NRORGULTATU
                )
                VALUES (
                    :NRCHKAGENDHISTORICO,   :NRCHECKLISTAGEND,  :NMCHECKLISTAGEND,  :DSCHKAGENDHISTORICO,
                    SYSDATE,                :IDTIPOHISTORICO,   'S',                :NRORG,
                    SYSDATE,                :CDOPERINCLUSAO,    :NRORGINCLUSAO,     SYSDATE,
                    :CDOPERULTATU,          :NRORGULTATU
                )";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getAprovacoes($parametros, $filtro)
    {
        $sql = "SELECT CHK.NRCHECKLISTAGEND, GER.NRGERENCIAMENTOCHK, GER.NMGERENCIAMENTOCHK, CHK.NMCHECKLISTAGEND, CHK.NRSEQCONTRATO,
                CHK.NRLOCALCLIENTE, LOC.NMLOCALCLIENTE, LOC.CDCLIENTE, CLI.NMRAZSOCCLIE, CHK.DTHORAAGEND, CHK.DSJUSTCANCELAMENTO,
                CHK.CDOPERADOR AS OPERRESPONSAVEL, OPERCHK.NMOPERADOR AS NMOPERRESPONSAVEL, GER.CDOPERADOR, OPERGER.NMOPERADOR,
                TO_CHAR(CHK.DTHORAAGEND, 'DD/MM') DTAGEND,  TO_CHAR(CHK.DTHORAAGEND, 'HH24:MI') HORAAGEND
                FROM FCM_CHECKLISTAGEND CHK
                JOIN FCM_GERENCIAMENTOCHK GER ON CHK.NRCHECKLISTAGEND = GER.NRCHECKLISTAGEND
                JOIN FCM_LOCALCLI LOC ON CHK.NRLOCALCLIENTE = LOC.NRLOCALCLIENTE
                JOIN CLIENTE CLI ON LOC.CDCLIENTE = CLI.CDCLIENTE
                JOIN OPERADOR OPERCHK ON CHK.CDOPERADOR = OPERCHK.CDOPERADOR
                JOIN OPERADOR OPERGER ON GER.CDOPERADOR = OPERGER.CDOPERADOR
                WHERE CHK.IDSITUACAOAGEND = 6
                AND GER.CDOPERADOR = :CDOPERADOR".$filtro;

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function atualizaStatusTarefa($parametros)
    {
        $sql = "UPDATE FCM_CHECKLISTAGEND
                SET IDSITUACAOAGEND = :IDSITUACAOAGEND,
                    DTHORAAGEND     = SYSDATE,
                    DTULTATU        = SYSDATE,
                    NRORGULTATU     = :NRORGULTATU,
                    CDOPERULTATU    = :CDOPERULTATU,
                    DTHRFINALAGEND  = SYSDATE
                WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function atualizaStatusVistoria($parametros)
    {
        $sql = "UPDATE FCM_GERENCIAMENTOCHK
                SET IDSITUACAOGERCHK = :IDSITUACAOGERCHK,
                    DTULTATU         = SYSDATE,
                    NRORGULTATU      = :NRORGULTATU,
                    CDOPERULTATU     = :CDOPERULTATU
                WHERE NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getOperadoresFiltrados($horarioInicial, $horarioFinal, $local)
    {
        $sql = "SELECT DISTINCT OPERADOR.CDOPERADOR, OPERADOR.NMOPERADOR
                FROM OPERADOR
                JOIN FCM_FUNCIONARIOSHIERARQ
                ON FCM_FUNCIONARIOSHIERARQ.CDOPERADOR = OPERADOR.CDOPERADOR
                JOIN FCM_HIERARQUIAFUNC
                ON FCM_HIERARQUIAFUNC.NRHIERARQUIAFUNC = FCM_FUNCIONARIOSHIERARQ.NRHIERARQUIAFUNC
                LEFT JOIN FCM_RELACHABOPER 
                ON FCM_RELACHABOPER.CDOPERADOR = OPERADOR.CDOPERADOR
                LEFT JOIN  FCM_RELACHABATIV
                ON  FCM_RELACHABATIV.NRHABILIDADE = FCM_RELACHABOPER.NRHABILIDADE
                LEFT JOIN FCM_TAREFACHK
                ON FCM_TAREFACHK.NRTAREFA = FCM_RELACHABATIV.NRTAREFA
                WHERE FCM_HIERARQUIAFUNC.NRLOCALCLIENTE IN (SELECT NRLOCALCLIENTE
                                                                FROM FCM_LOCALCLI
                                                            START WITH NRLOCALCLIENTE = $local
                                                            CONNECT BY PRIOR NRLOCALCLIENTEPAI = NRLOCALCLIENTE)
                AND OPERADOR.CDOPERADOR NOT IN (SELECT DISTINCT(CDOPERADOR)
                    FROM FCM_CHECKLISTAGEND
                    WHERE IDATIVO = 'S' AND
                    CDOPERADOR IS NOT NULL AND
                    (TO_DATE('".$horarioInicial."', 'DD-MM-YYYY HH24:MI') >= DTHORAAGEND AND TO_DATE('".$horarioInicial."', 'DD-MM-YYYY HH24:MI') <= DTHRFINALAGEND)
                    OR (TO_DATE('".$horarioFinal."', 'DD-MM-YYYY HH24:MI') >= DTHORAAGEND AND TO_DATE('".$horarioFinal."', 'DD-MM-YYYY HH24:MI') <= DTHRFINALAGEND)
                    OR (TO_DATE('".$horarioInicial."', 'DD-MM-YYYY HH24:MI') >= DTHORAAGEND AND TO_DATE('".$horarioFinal."', 'DD-MM-YYYY HH24:MI') <= DTHRFINALAGEND))";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getOperadoresAprovacoes($parametros)
    {

        $sql = "SELECT CDOPERADOR, NMOPERADOR
                FROM OPERADOR
                WHERE CDOPERADOR IN ($parametros)
                ORDER BY NMOPERADOR";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function defineNovoHorarioOperadorTarefa($parametros)
    {
        $sql = "UPDATE FCM_CHECKLISTAGEND
                SET DTHORAAGEND = :DTHORAAGEND,
                    CDOPERULTATU = :CDOPERULTATU,
                    NRORGULTATU = :NRORGULTATU,
                    DTHRFINALAGEND = :DTHRFINALAGEND,
                    CDOPERADOR = :CDOPERADOR
                WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getFotosAprovacao($parametros)
    {

        $sql = "SELECT FTAGEND.NRFOTOTAREFAAGEND, FTAGEND.DSFOTOTAREFAAGEND, CHKAGEND.NRCHECKLISTAGEND, CHKAGEND.NMCHECKLISTAGEND
                FROM FCM_FOTOTAREFAAGEND FTAGEND
                JOIN FCM_TAREFAAGEND TRAGEND 
                ON TRAGEND.NRTAREFAAGEND = FTAGEND.NRTAREFAAGEND
                JOIN FCM_CHECKLISTAGEND CHKAGEND
                ON CHKAGEND.NRCHECKLISTAGEND = TRAGEND.NRCHECKLISTAGEND
                WHERE CHKAGEND.NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }
}
