<?php

namespace FM\Factory;

use Doctrine\ORM\EntityManager;
use FM\Traits\TQuery;

class MinhasTarefasFactory
{
    use TQuery;
    protected $entityManager;
    protected $connection;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection       = $entityManager->getConnection();
        $this->entityManager    = $entityManager;
    }

    // Funções da tela de listagem ed tarefas
    public function getTarefasListadas($listaOperadores, $filtros, $parametros)
    {
        $sql = "SELECT CA.NRCHECKLISTAGEND, CA.NRLOCALCLIENTE, CA.NRCHECKLIST, CA.CDOPERADOR, CA.IDSITUACAOAGEND, CA.NRSEQCONTRATO, LC.CDCLIENTE, CA.DSJUSTCANCELAMENTO,
                    TO_CHAR(CA.DTHORAAGEND, 'DD/MM') DTAGEND,  TO_CHAR(CA.DTHORAAGEND, 'HH24:MI') HORAAGEND, CA.NMCHECKLISTAGEND, LC.NMLOCALCLIENTE, LC.NRLOCALCLIENTEPAI AS LOCALPAI,
                    LCP.NMLOCALCLIENTE AS NMLOCALPAI, CHK.NMCHECKLIST, F.NMOPERADOR, C.NRCONTRATOFCT, CT.NMRAZSOCCLIE, DTHORAAGEND, S.NRSOLICITACAO,
                    FCM_EQUIPE.NMEQUIPE,
                    FCM_EQUIPETAREFA.NREQUIPE,
                    FCM_EQUIPETAREFA.NREQUIPETAREFA,
                                    CASE CA.IDSITUACAOAGEND 
                                    WHEN '1' THEN 'Pendente'
                                    WHEN '2' THEN 'Em andamento'
                                    WHEN '3' THEN 'Cancelado'
                                    WHEN '4' THEN 'Concluído'
                                    WHEN '5' THEN 'Atrasado'
                                    WHEN '6' THEN 'Aprovação pendente'
                                    ELSE NULL END AS SITUACAO
                                FROM FCM_CHECKLISTAGEND CA
                                JOIN FCM_LOCALCLI LC
                                ON LC.NRLOCALCLIENTE = CA.NRLOCALCLIENTE
                                JOIN FCM_LOCALCLI LCP
                                ON LCP.NRLOCALCLIENTE = LC.NRLOCALCLIENTEPAI
                                LEFT JOIN CLIENTE CT
                                ON CT.CDCLIENTE = LC.CDCLIENTE
                                LEFT JOIN FCM_CHECKLIST CHK
                                ON CA.NRCHECKLIST = CHK.NRCHECKLIST
                                LEFT JOIN OPERADOR F
                                ON F.CDOPERADOR = CA.CDOPERADOR
                                LEFT JOIN FCT_CONTRATO C
                                ON C.NRSEQCONTRATO = CA.NRSEQCONTRATO
                                LEFT JOIN FCM_SOLICITACAOTAREFAS S
                                ON S.NRCHECKLISTAGEND = CA.NRCHECKLISTAGEND
                                 LEFT JOIN 
                                    FCM_EQUIPETAREFA ON FCM_EQUIPETAREFA.NRCHECKLISTAGEND = CA.NRCHECKLISTAGEND
                                LEFT JOIN 
                                FCM_EQUIPE ON FCM_EQUIPE.NREQUIPE = FCM_EQUIPETAREFA.NREQUIPE
                                WHERE ((CA.CDOPERADOR IN ($listaOperadores)) -- Tarefas criadas para operador específico
                                OR ((CA.CDOPERADOR IS NULL) AND (CA.IDTAREFAEQUIPE = 'N')) -- Tarefas sem operador
                                OR (FCM_EQUIPETAREFA.NREQUIPE IN 
                                    (SELECT DISTINCT FCM_EQUIPE.NREQUIPE 
                                        FROM FCM_EQUIPE
                                        JOIN FCM_RELACEQUIPEOPER ON FCM_RELACEQUIPEOPER.NREQUIPE = FCM_EQUIPE.NREQUIPE
                                        AND FCM_RELACEQUIPEOPER.NRORG = FCM_EQUIPE.NRORG
                                        WHERE FCM_RELACEQUIPEOPER.CDOPERADOR IN ($listaOperadores))) -- Tarefas de equipe
                                        OR CA.CDOPERINCLUSAO = :CDOPERADOR) -- Operador de inclusão
                                " . $filtros . "
                             ORDER BY CA.DTHORAAGEND";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }


    public function getFotosTarefas($parametros)
    {

        $sql = "SELECT FCM_FOTOTAREFAAGEND.NRFOTOTAREFAAGEND, FCM_FOTOTAREFAAGEND.DSFOTOTAREFAAGEND, FCM_CHECKLISTAGEND.NRCHECKLISTAGEND, FCM_CHECKLISTAGEND.NMCHECKLISTAGEND
                    FROM FCM_FOTOTAREFAAGEND
                    JOIN FCM_TAREFAAGEND 
                    ON FCM_TAREFAAGEND.NRTAREFAAGEND = FCM_FOTOTAREFAAGEND.NRTAREFAAGEND
                    JOIN FCM_CHECKLISTAGEND 
                    ON FCM_CHECKLISTAGEND.NRCHECKLISTAGEND = FCM_TAREFAAGEND.NRCHECKLISTAGEND
                    WHERE FCM_CHECKLISTAGEND.NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function excluirFotoTarefas($parametros)
    {

        $sql = "DELETE FROM FCM_FOTOTAREFAAGEND
                    WHERE NRFOTOTAREFAAGEND = :NRFOTOTAREFAAGEND";

        $this->connection->executeStatement($sql, $parametros);
    }

    //Funções da Tela Minhas Tarefas
    public function getCodTarefaAgend($parametros)
    {

        $sql = "SELECT NRTAREFAAGEND
                    FROM FCM_TAREFAAGEND
                    WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function anexarImagemTarefas($parametros)
    {

        $sql = "INSERT INTO FCM_FOTOTAREFAAGEND (NRFOTOTAREFAAGEND, NRTAREFAAGEND, DSFOTOTAREFAAGEND, IDATIVO, NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, DSTYPE, NRSIZE)
        VALUES (:NRFOTOTAREFAAGEND, :NRTAREFAAGEND, :DSFOTOTAREFAAGEND, 'S', :NRORG, SYSDATE, :CDOPERINCLUSAO, :NRORGINCLUSAO, :DSTYPE, :NRSIZE)";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getMinhasTarefas($listaOperadores, $filtros, $parametros)
    {
         $sql = "SELECT
                    FCM_CHECKLISTAGEND.NRCHECKLISTAGEND,
                    FCM_CHECKLISTAGEND.NMCHECKLISTAGEND,
                    FCM_CHECKLISTAGEND.IDSITUACAOAGEND,
		    TO_CHAR(FCM_CHECKLISTAGEND.DTHORAAGEND, 'DD/MM') DTAGEND,
                    TO_CHAR(FCM_CHECKLISTAGEND.DTHORAAGEND, 'HH24:MI') HORAAGEND,
                    TO_CHAR(FCM_CHECKLISTAGEND.DTHORAAGEND, 'DD/MM/YYYY HH24:MI') AS DTHORAAGEND,
                    TO_CHAR(FCM_CHECKLISTAGEND.DTHRFINALAGEND, 'DD/MM/YYYY HH24:MI') AS DTHRFINALAGEND,
                    TO_CHAR(FCM_CHECKLISTAGEND.DTINCLUSAO, 'DD/MM/YYYY HH24:MI:SS') AS DTINCLUSAO,
                    FCM_LOCALCLI.NRLOCALCLIENTE, 
                    FCM_LOCALCLI.NMLOCALCLIENTE, 
		            FCM_LOCALCLI.NRLOCALCLIENTEPAI AS LOCALPAI,
		            LCP.NMLOCALCLIENTE AS NMLOCALPAI,
                    FCM_LOCALCLI.NRESTRUTURAM,
                    FCM_TIPOLOCALCLI.NRTIPOLOCALCLI,
                    FCM_TIPOLOCALCLI.NMTIPOLOCALCLI, 
                    FCT_CONTRATO.NRSEQCONTRATO,
                    FCM_CHECKLIST.NRCHECKLIST, 
                    FCM_CHECKLIST.NMCHECKLIST, 
                    FCM_CHECKLISTAGEND.IDTIPORECORRENCIA, 
                    FCM_CHECKLISTAGEND.CDOPERINCLUSAO,
                    OPERADOR.NMOPERADOR, 
                    FCM_CHECKLISTAGEND.CDOPERADOR, 
                    FCM_EQUIPE.NMEQUIPE,
                    FCM_EQUIPETAREFA.NREQUIPE,
                    FCM_EQUIPETAREFA.NREQUIPETAREFA,
                    FCM_LOCALCLI.CDCLIENTE, 
                    CLIENTE.NMRAZSOCCLIE,
                    CLIENTE.NMFANTCLIE, 
                    FCT_CONTRATO.NRCONTRATOFCT, 
                    FCM_CHECKLISTAGEND.IDATIVO, 
                    FCM_GERENCIAMENTOCHK.CDOPERADOR AS CDOPERADORPAI,
                    FCM_GERENCIAMENTOCHK.IDOBRIGAOBSERVACAO,
                    FCM_GERENCIAMENTOCHK.NRGERENCIAMENTOCHK,
                    FCM_CHECKLISTAGEND.IDTIPOMARCACAOTAREFA, 
                    FCM_CHECKLISTAGEND.NRPRIORIDADETAREFA, 
                    FCM_CHECKLISTAGEND.IDTAREFAEQUIPE,
                    FCM_CHECKLISTAGEND.NRESCOPOSTAREFA,
                    FCM_ESCOPOSTAREFA.NMESCOPOSTAREFA,
                    FCM_RELCHKAGENDMODPOP.NRMODELOPOP,
                    FCM_RELCHKAGENDMODPOP.DSOBSERVACAO,
                    FCM_RELCHKAGENDMODPOP.NRRELCHKAGENDMODPOP,
                    FCM_SOLICITACAOTAREFAS.NRSOLICITACAO,
                    (SELECT RTRIM(XMLAGG(XMLELEMENT(E, FCM_RELCHKAGENDEPI.NREPI || ', ').EXTRACT('//text()')).GETCLOBVAL(), ', ') 
                        FROM FCM_RELCHKAGENDEPI
                        WHERE  FCM_RELCHKAGENDEPI.NRCHECKLISTAGEND = FCM_CHECKLISTAGEND.NRCHECKLISTAGEND
                        AND FCM_RELCHKAGENDEPI.IDATIVO = 'S' ) AS NREPI,
                    (SELECT LISTAGG(NRCRITERIOTAREFACHK, ', ') WITHIN GROUP (ORDER BY NRCRITERIOTAREFACHK) 
                        FROM FCM_RELCRITERIOTAGTAREFACHK
                        WHERE   FCM_RELCRITERIOTAGTAREFACHK.NRTAREFACHK IN 
                            (SELECT NRTAREFACHK FROM FCM_TAREFACHK WHERE FCM_TAREFACHK.NRCHECKLIST = FCM_CHECKLISTAGEND.NRCHECKLIST)  ) AS NRCRITERIOTAREFACHK,
                    (SELECT  LISTAGG(NRTAREFACHK, ', ') WITHIN GROUP (ORDER BY NRTAREFACHK) 
                            FROM  FCM_TAREFACHK 
                            WHERE  FCM_TAREFACHK.NRCHECKLIST = FCM_CHECKLISTAGEND.NRCHECKLIST ) AS NRTAREFACHK,
                     (SELECT RTRIM(XMLAGG(XMLELEMENT(E, FCM_ATIVIDADECHK.NRATIVIDADECHK || ',').EXTRACT('//text()')).GETCLOBVAL(), ',')
                            FROM  FCM_ATIVIDADECHK
                            WHERE  FCM_CHECKLISTAGEND.NRCHECKLIST = FCM_ATIVIDADECHK.NRCHECKLIST ) AS NRATIVIDADECHK, 
                            CASE FCM_CHECKLISTAGEND.IDSITUACAOAGEND WHEN '1' THEN 'Pendente'
                            WHEN '2' THEN 'Em andamento'
                            WHEN '5' THEN 'Atrasado'
                            ELSE NULL END AS SITUACAO
                FROM 
                    FCM_CHECKLISTAGEND
                JOIN 
                    FCM_LOCALCLI ON FCM_CHECKLISTAGEND.NRLOCALCLIENTE = FCM_LOCALCLI.NRLOCALCLIENTE
		        JOIN FCM_LOCALCLI LCP ON LCP.NRLOCALCLIENTE = FCM_LOCALCLI.NRLOCALCLIENTEPAI
                JOIN 
                    CLIENTE ON CLIENTE.CDCLIENTE = FCM_LOCALCLI.CDCLIENTE
                JOIN 
                    FCM_TIPOLOCALCLI ON FCM_LOCALCLI.NRTIPOLOCALCLI = FCM_TIPOLOCALCLI.NRTIPOLOCALCLI
                JOIN 
                    FCM_CHECKLIST ON FCM_CHECKLISTAGEND.NRCHECKLIST = FCM_CHECKLIST.NRCHECKLIST
                LEFT JOIN 
                    FCM_GERENCIAMENTOCHK ON FCM_GERENCIAMENTOCHK.NRCHECKLISTAGEND = FCM_CHECKLISTAGEND.NRCHECKLISTAGEND
                LEFT JOIN 
                    OPERADOR ON FCM_CHECKLISTAGEND.CDOPERADOR = OPERADOR.CDOPERADOR
                LEFT JOIN 
                    FCT_CONTRATO ON FCT_CONTRATO.NRSEQCONTRATO = FCM_CHECKLISTAGEND.NRSEQCONTRATO
                LEFT JOIN 
                    FCM_EQUIPETAREFA ON FCM_EQUIPETAREFA.NRCHECKLISTAGEND = FCM_CHECKLISTAGEND.NRCHECKLISTAGEND
                LEFT JOIN 
                    FCM_EQUIPE ON FCM_EQUIPE.NREQUIPE = FCM_EQUIPETAREFA.NREQUIPE
                LEFT JOIN 
                    FCM_RELCHKAGENDMODPOP ON FCM_CHECKLISTAGEND.NRCHECKLISTAGEND = FCM_RELCHKAGENDMODPOP.NRCHECKLISTAGEND
                LEFT JOIN 
                    FCM_ESCOPOSTAREFA ON FCM_CHECKLISTAGEND.NRESCOPOSTAREFA = FCM_ESCOPOSTAREFA.NRESCOPOSTAREFA
                LEFT JOIN FCM_SOLICITACAOTAREFAS
                            ON FCM_SOLICITACAOTAREFAS.NRCHECKLISTAGEND = FCM_CHECKLISTAGEND.NRCHECKLISTAGEND
                WHERE 
                    ((FCM_CHECKLISTAGEND.CDOPERADOR IN ($listaOperadores)) -- Tarefas criadas para operador específico
                        OR ((FCM_CHECKLISTAGEND.CDOPERADOR IS NULL) AND (FCM_CHECKLISTAGEND.IDTAREFAEQUIPE = 'N')) -- Tarefas sem operador
                        OR (FCM_EQUIPETAREFA.NREQUIPE IN 
                            (SELECT DISTINCT FCM_EQUIPE.NREQUIPE 
                            FROM FCM_EQUIPE
                            JOIN FCM_RELACEQUIPEOPER ON FCM_RELACEQUIPEOPER.NREQUIPE = FCM_EQUIPE.NREQUIPE
                            AND FCM_RELACEQUIPEOPER.NRORG = FCM_EQUIPE.NRORG
                            WHERE FCM_RELACEQUIPEOPER.CDOPERADOR IN ($listaOperadores)))) -- Tarefas de equipe
                       AND FCM_CHECKLISTAGEND.IDATIVO = 'S'
			        AND FCM_CHECKLISTAGEND.IDSITUACAOAGEND IN (1,2,5)" . $filtros . "
                    ORDER BY FCM_CHECKLISTAGEND.DTHORAAGEND ASC, FCM_CHECKLISTAGEND.IDSITUACAOAGEND DESC";
                
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getTarefasPorOperador($operadores)
    {

        $sql = "SELECT NMCHECKLISTAGEND || ' - ' || TO_CHAR(DTHORAAGEND, 'DD/MM HH24:MI') AS NMCHECKLISTAGEND, NRCHECKLISTAGEND
                    FROM FCM_CHECKLISTAGEND
                    WHERE CDOPERADOR IN ({$operadores})
                    AND IDSITUACAOAGEND IN ('1', '2')
                    AND IDATIVO = 'S'";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    // Update para alterar o status da tarefa
    // Quando iniciar a tarefa , passar o valor '2' / Quando finalizar, passar o valor '4'  / Quando reportar, passar o valor 3
    // DSJUSTCANCELAMENTO = Deve ser preenchido somente quando for reportar. Para as outras ações, deve ser passado "NULL"
    public function alterarStatusTarefa($parametros)
    {
        $sql = "UPDATE FCM_CHECKLISTAGEND
                    SET IDSITUACAOAGEND = :IDSITUACAOAGEND,
                    DTULTATU = SYSDATE,
                    DSJUSTCANCELAMENTO = :DSJUSTCANCELAMENTO, 
                    CDOPERULTATU = :CDOPERULTATU, 
                    NRORGULTATU = :NRORGULTATU
                    WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function alterarResposanvelTarefa ($parametros)
    {
        $sql = "UPDATE FCM_CHECKLISTAGEND
                    SET CDOPERADOR = :CDOPERADOR,
                    DTULTATU = SYSDATE,
                    CDOPERULTATU = :CDOPERULTATU, 
                    NRORGULTATU = :NRORGULTATU
                    WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function salvarObservacao($parametros)
    {
        $sql = "UPDATE FCM_TAREFAAGEND
                    SET DSOBSTAREFAAGEND = :DSOBSTAREFAAGEND,
                        CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU,
                        DTULTATU = SYSDATE
                    WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";
        
        $this->connection->executeStatement($sql, $parametros);
    }

    public function upStatusVistoryCanc($parametros)
    {

        $sql = "UPDATE FCM_GERENCIAMENTOCHK
                SET IDSITUACAOGERCHK = :IDSITUACAOGERCHK,
                    DTULTATU = SYSDATE,
                    CDOPERULTATU = :CDOPERULTATU, 
                    NRORGULTATU = :NRORGULTATU
                WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        $this->connection->executeStatement($sql, $parametros);
    }


    // Update de finalização do detalhamento
    // IDREALIZADO = Somente dos checks que foram marcados
    public function alterarStatusItens($parametros, $nrtarefa)
    {
        $sql = "UPDATE FCM_TAREFAAGEND
                    SET IDREALIZADO = :IDREALIZADO,
                        DTULTATU = SYSDATE,
                        CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU
                WHERE NRTAREFAAGEND IN ($nrtarefa)
                AND NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        $this->connection->executeStatement($sql, $parametros);
    }

    // Funções da Tela de Detalhamento
    public function getItensTarefas($parametros)
    {

        $sql = "SELECT TA.NRTAREFAAGEND, TA.NRCHECKLISTAGEND, TA.CDOPERADOR, TO_CHAR(TA.DTHORATAREFAAGEND, 'DD/MM HH24:MI') DTHORATAREFAAGEND, TA.DSOBSTAREFAAGEND,
              TA.NRTAREFACHK, TA.IDREALIZADO, TF.NMTAREFA
               FROM FCM_TAREFAAGEND TA
               JOIN FCM_CHECKLISTAGEND  CA
               ON TA.NRCHECKLISTAGEND = CA.NRCHECKLISTAGEND
               JOIN FCM_TAREFACHK T
               ON T.NRTAREFACHK = TA.NRTAREFACHK
               JOIN FCM_TAREFA TF
               ON T.NRTAREFA = TF.NRTAREFA
               WHERE CA.NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getDetalhesTarefa($parametros)
    {

        $sql = "SELECT CA.NRCHECKLISTAGEND, CA.NRLOCALCLIENTE, CA.NRCHECKLIST, CA.CDOPERADOR, CA.IDSITUACAOAGEND,
        TO_CHAR(CA.DTHORAAGEND, 'DD/MM HH24:MI') DTHORAAGEND, CA.NMCHECKLISTAGEND, LC.NMLOCALCLIENTE, LC.NRLOCALCLIENTEPAI AS LOCALPAI,
        LCP.NMLOCALCLIENTE AS NMLOCALPAI, CHK.NMCHECKLIST, F.NMOPERADOR, CA.IDOBRIGAOBSERVACAO,
                  CASE CA.IDSITUACAOAGEND WHEN '1' THEN 'Pendente'
                  WHEN '2' THEN 'Em andamento'
                  WHEN '5' THEN 'Atrasado'
                  ELSE NULL END AS IDSITUACAOAGEND
              FROM FCM_CHECKLISTAGEND CA
              JOIN FCM_LOCALCLI LC
              ON LC.NRLOCALCLIENTE = CA.NRLOCALCLIENTE
              JOIN FCM_LOCALCLI LCP
              ON LCP.NRLOCALCLIENTE = LC.NRLOCALCLIENTEPAI
              JOIN FCM_CHECKLIST CHK
              ON CA.NRCHECKLIST = CHK.NRCHECKLIST
              JOIN OPERADOR F
              ON F.CDOPERADOR = CA.CDOPERADOR
              WHERE CA.NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function qtdTarefasAtivas() // $listaOperadores
    {
        $sql = "SELECT COUNT (IDSITUACAOAGEND) AS TAREFAATIVA
                FROM FCM_CHECKLISTAGEND
                WHERE IDSITUACAOAGEND = '2'
                
                ";
            // AND CDOPERADOR IN ({$listaOperadores})
        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function statusCheck($parametros)
    {

        $sql = "SELECT COUNT(IDSITUACAOAGEND)
               FROM FCM_CHECKLISTAGEND
               WHERE IDSITUACAOAGEND = '2'
               AND CDOPERADOR = :CDOPERADOR";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    // ------------------------------ FUNÇÔES GEOLOCALIZAÇÃO ------------------------------
    public function getGeolocalizacao($params)
    {
        $sql = "SELECT NRLOCALCLIENTE, NRGEOLOCALIZACAO
                FROM FCM_LOCALCLI
                WHERE NRLOCALCLIENTE = $params";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function getParametrizacao()
    {
        $sql = "SELECT IDUTILIZAGEOLOCAL, IDUTILIZAGEOLOCALINITAR
        FROM FCM_PARAMGERAL";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    // funções de ordenação - também usadas na tela de Vistoria
    public function insertOrdenacao($parametros)
    {
        $sql = "INSERT INTO FCM_ORDENACAOAPP(NRORDENCAOAPP, CDOPERADOR, NMTELA, NMCAMPO, IDSENTIDO, NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO)
        VALUES (:NRORDENCAOAPP, :CDOPERADOR, :NMTELA, :NMCAMPO, :IDSENTIDO, :NRORG, SYSDATE, :CDOPERINCLUSAO, :NRORGINCLUSAO)";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function updateOrdenacao($parametros)
    {
        $sql = "UPDATE FCM_ORDENACAOAPP
                    SET NMCAMPO = :NMCAMPO,
                        IDSENTIDO = :IDSENTIDO,
                        DTULTATU = SYSDATE,
                        CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU
                    WHERE CDOPERADOR = :CDOPERADOR
                    AND NRORDENCAOAPP = :NRORDENCAOAPP";
        
        $this->connection->executeStatement($sql, $parametros);
    }

    public function getOrdenacao($parametros)
    {
        $sql = "SELECT NRORDENCAOAPP, NMTELA, NMCAMPO, IDSENTIDO
                    FROM FCM_ORDENACAOAPP
                    WHERE CDOPERADOR = :CDOPERADOR
                    AND NMTELA = :NMTELA";
        
        // $var = 
        // var_dump($var);
        // die;
        return $this->connection->executeStatement($sql, $parametros);
    }

    public function deleteOrdenacao($parametros)
    {
        $sql = "DELETE FROM FCM_ORDENACAOAPP
                    WHERE NRORDENCAOAPP = :NRORDENCAOAPP";
        
        $this->connection->executeStatement($sql, $parametros);
    }

    public function getSolicitacoesVinculadas($parametros)
    {
        $sql = "SELECT FCM_SOLICITACAOTAREFAS.NRSOLICITACAO, FCM_SOLICITACAO.NMSOLICITACAO, FCM_SOLICITACAO.DSSOLICITACAO
                    FROM FCM_SOLICITACAOTAREFAS
                    JOIN FCM_SOLICITACAO
                    ON FCM_SOLICITACAO.NRSOLICITACAO = FCM_SOLICITACAOTAREFAS.NRSOLICITACAO
                    WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getNomeStatusTarefa($parametros)
    {
        $sql = "SELECT NMCHECKLISTAGEND, IDSITUACAOAGEND, IDTAREFAEQUIPE, CDOPERADOR
                FROM FCM_CHECKLISTAGEND
                WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function atualizaHistoricoTarefa($parametros)
    {
        $sql = "INSERT INTO FCM_CHKAGENDHISTORICO (
                    NRCHKAGENDHISTORICO,    NRCHECKLISTAGEND,   NMCHECKLISTAGEND,   DSCHKAGENDHISTORICO,
                    DTCHKAGENDHISTORICO,    IDTIPOHISTORICO,    IDATIVO,            NRORG,
                    DTINCLUSAO,             CDOPERINCLUSAO,     NRORGINCLUSAO,      DTULTATU,
                    CDOPERULTATU,           NRORGULTATU
                )
                VALUES (
                    :NRCHKAGENDHISTORICO,   :NRCHECKLISTAGEND,  :NMCHECKLISTAGEND,  :DSCHKAGENDHISTORICO,
                    SYSDATE,                :IDTIPOHISTORICO,   'S',                :NRORG,
                    SYSDATE,                :CDOPERINCLUSAO,    :NRORGINCLUSAO,     SYSDATE,
                    :CDOPERULTATU,          :NRORGULTATU
                )";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getVistoriaVinculada($parametros)
    {
        $sql = "SELECT NRGERENCIAMENTOCHK, NMGERENCIAMENTOCHK
                FROM FCM_GERENCIAMENTOCHK
                WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function atualizaHistoricoVistoria($parametros)
    {
        $sql = "INSERT INTO FCM_GERCHKHISTORICO (
                    NRGERCHKHISTORICO,      NRGERENCIAMENTOCHK, NMGERENCIAMENTOCHK, DSGERENCIAMENTOCHK,
                    DTHISTGERENCIAMENTOCHK, IDTIPOHISTORICO,    IDATIVO,            NRORG,
                    DTINCLUSAO,             CDOPERINCLUSAO,     NRORGINCLUSAO,      DTULTATU,
                    CDOPERULTATU,           NRORGULTATU
                )
                VALUES (
                    :NRGERCHKHISTORICO,     :NRGERENCIAMENTOCHK, :NMGERENCIAMENTOCHK, :DSGERENCIAMENTOCHK,
                    SYSDATE,                :IDTIPOHISTORICO,    'S',                 :NRORG,
                    SYSDATE,                :CDOPERINCLUSAO,     :NRORGINCLUSAO,      SYSDATE,
                    :CDOPERULTATU,          :NRORGULTATU
                )";

        $this->connection->executeStatement($sql, $parametros);
    }
}
