import {
    Text, CheckboxMultiple, Textarea, Button, LoadingService, Form, Modal, ModalService, SelectMultiple, DateRange, FileInput, TextInput,
    Time,
    Select,
    Date,
} from '@zeedhi/common';
import {
    IDictionary, Http, Metadata, IEventParam, Router, SimpleDatasource, dayjs,
} from '@zeedhi/core';
import {
    IterableCarousel, IterableComponentRender,
} from '@zeedhi/teknisa-components-common';
import { TekIterableComponentRender } from '@zeedhi/teknisa-components-vuetify';
import { Utilities } from '@/util/Utilities';
import { ZdCard } from '@zeedhi/vuetify';
import { HttpCRUDTranslator } from '@/http-crud-translator/http-crud-translator';
import FileUpload from './FileUpload';

export class Fm00002VistoriasController {
    public visibilidadeFrameDetalhes = false;

    public visibilidadeTelaPrincipal = true;

    public tituloLocal = '';

    public modalAnexarImagem!: Modal;

    public modalVisualizarImagens!: Modal;

    public modalFiltrarVistorias!: Modal;

    public modalInformacoes!: Modal;

    public modalDadosAprovacao!: Modal;

    public modalRecusarReport!: Modal;

    public modalImagensAprovacao!: Modal;

    public modalFiltrarAprovacoes!: Modal;

    public nrGerenciamentoChk: any = '';

    public vistoria: any = '';

    public contrato: any = '';

    public cliente: any = '';

    public tarefa: any = '';

    public local: any = '';

    public data: any = '';

    public funcionario: any = '';

    public supervisor: any = '';

    public situacao: any = '';

    public visibilidadeCarroselImagens: boolean = false;

    public disableCheckbox = false;

    public readonlyObservacao = false;

    public disableVistoria = false;

    public disableSalvarVistoria = false;

    public disableAnexarFoto = false;

    public tipoOrdenacao = '';

    public tipoOrdenacaoAprovacoes = '';

    public nrChkAgendRecusar = '';

    public nrChkAgendImagem = '';

    public ordenarCards({ component }: IEventParam<Button>) {
        const iterable = Metadata.getInstance<TekIterableComponentRender>('iterable-cards-listagem-vistorias');

        iterable.datasource.clearOrder();
        if (component.name === 'botao-ordenar-vistoria') {
            iterable.datasource.addOrder('NMGERENCIAMENTOCHK', 'ASC');
        } else if (component.name === 'botao-ordenar-local') {
            iterable.datasource.addOrder('NMLOCALCLIENTE', 'ASC');
        } else if (component.name === 'botao-ordenar-data') {
            iterable.datasource.addOrder('DATACOMPLETA', 'DESC');
        } else {
            iterable.datasource.clearOrder();
        }

        const { order } = iterable.datasource;
        if (order) {
            const campo = (order.length === 0) ? '' : order[0].split('.')[0];
            this.exibirTipoOrdenacao(campo);
        }
        iterable.datasource.setPage(1);
        this.inserirOrdenacao({ component: iterable });

        iterable.datasource.setPage(1);
    }

    public exibirTipoOrdenacao(name: any) {
        const visibilidadeText = Metadata.getInstance<Text>('titulo-ordenacao');

        switch (name) {
            case 'NMGERENCIAMENTOCHK':
                this.tipoOrdenacao = 'Ordenado por nome da Tarefa';
                visibilidadeText.isVisible = true;
                break;
            case 'NMLOCALCLIENTE':
                this.tipoOrdenacao = 'Ordenado por Local';
                visibilidadeText.isVisible = true;
                break;
            case 'DATACOMPLETA':
                this.tipoOrdenacao = 'Ordenado por Data';
                visibilidadeText.isVisible = true;
                break;
            default:
                this.tipoOrdenacao = '';
                visibilidadeText.isVisible = false;
                break;
        }
    }

    public inserirOrdenacao({ component }: IEventParam<TekIterableComponentRender>) {
        const { order } = component.datasource;
        if (order) {
            Http.post('/insertOrdenacao', {
                NMTELA: 'Vistorias',
                NMCAMPO: (order.length === 0) ? '' : order[0].split('.')[0],
                IDSENTIDO: (order.length === 0) ? '' : order[0].split('.')[1],
            }).then(() => {
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            });
        }
    }

    public onMountedOrdenacao({ component }: IEventParam<TekIterableComponentRender>) {
        Http.post('/getOrdenacao', {
            NMTELA: 'Vistorias',
        }).then((response: IDictionary) => {
            if (response.data.length !== 0 && typeof response.data.length !== 'undefined') {
                component.datasource.clearOrder();
                component.datasource.addOrder(response.data[0].NMCAMPO, response.data[0].IDSENTIDO);
                this.exibirTipoOrdenacao(response.data[0].NMCAMPO);
                Utilities.showSuccessMessage();
            }
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        });
    }

    public sortFunction(value1: any, value2: any, columnName: string): boolean {
        if (columnName === 'DATACOMPLETA') {
          return (dayjs(value1, 'DD/MM/YYYY HH24:MI').isAfter(dayjs(value2, 'DD/MM/YYYY HH24:MI')));
        }
        return (value1 > value2);
    }

    public carregarCardsVistorias({ component }: any) {
        component.datasource.setFilter({
            TIPO: 1,
        });
        this.onMountedOrdenacao({ component });
    }

    public async criarModais() {
        this.modalVisualizarImagens = await ModalService.createFromJsonPost('', { jsonPath: 'fm_00002_000_vistoria/modal/fm_00002_000_visualizar_imagens' });
        this.modalFiltrarVistorias = await ModalService.createFromJsonPost('', { jsonPath: 'fm_00002_000_vistoria/modal/fm_00002_000_filtrar_vistorias' });
        this.modalInformacoes = await ModalService.createFromJsonPost('', { jsonPath: 'fm_00002_000_vistoria/modal/fm_00002_000_dados_vistoria' });
        this.modalAnexarImagem = await ModalService.createFromJsonPost('', { jsonPath: 'fm_00002_000_vistoria/modal/fm_00002_000_anexar_imagens' });
        this.modalDadosAprovacao = await ModalService.createFromJson('fm_00002_000_vistoria/modal/fm_00002_000_dados_aprovacao', true, true);
        this.modalRecusarReport = await ModalService.createFromJson('fm_00002_000_vistoria/modal/fm_00002_000_recusar_report', true, true);
        this.modalFiltrarAprovacoes = await ModalService.createFromJson('fm_00002_000_vistoria/modal/fm_00002_000_filtrar_aprovacoes', true, true);
    }

    public destruirModais() {
        this.modalVisualizarImagens?.destroy();
        this.modalFiltrarVistorias?.destroy();
        this.modalInformacoes?.destroy();
        this.modalAnexarImagem?.destroy();
        this.modalDadosAprovacao?.destroy();
        this.modalRecusarReport?.destroy();
    }

    public async exibirModalVisualizarImagens({ component }: any) {
        const nr = component.name.split('_')[1];
        this.nrGerenciamentoChk = nr;
        this.modalVisualizarImagens.show();
    }

    public async exibirModalFiltros() {
        this.modalFiltrarVistorias.show();
    }

    public fecharModalInformacoes() {
        this.modalInformacoes.hide();
    }

    public fecharModalVisualizarImagens() {
        this.modalVisualizarImagens.hide();
    }

    public fecharModalFiltros() {
        this.modalFiltrarVistorias.hide();
    }

    public abrirModalAnexar() {
        this.modalAnexarImagem.show();
    }

    public fecharModalAnexar() {
        this.modalAnexarImagem.hide();
    }

    public abrirModalDadosAprovacao() {
        this.modalDadosAprovacao.show();
    }

    public fecharModalDadosAprovacao() {
        this.modalDadosAprovacao.hide();
    }

    public abrirModalRecusarReport() {
        this.modalRecusarReport.show();
    }

    public fecharModalRecusarReport() {
        this.modalRecusarReport.hide();
    }

    public async abrirModalImagensAprovacao() {
        this.modalImagensAprovacao = await ModalService.createFromJson('fm_00002_000_vistoria/modal/fm_00002_000_imagens_aprovacao', true, true);
        this.modalImagensAprovacao.show();
    }

    public fecharModalImagensAprovacao() {
        this.modalImagensAprovacao.hide();
        this.modalImagensAprovacao?.destroy();
    }

    public abrirModalFiltrarAprovacoes() {
        this.modalFiltrarAprovacoes.show();
    }

    public fecharModalFiltrarAprovacoes() {
        this.modalFiltrarAprovacoes.hide();
    }

    public filtrarCards() {
        const iterable = Metadata.getInstance<IterableComponentRender>('iterable-cards-listagem-vistorias');

        iterable.datasource.setFilter({
            CDCLIENTE: Metadata.getInstance<SelectMultiple>('filtro-cliente').value,
            CDOPERADOR: Metadata.getInstance<SelectMultiple>('filtro-operador').value,
            IDSITUACAOGERCHK: Metadata.getInstance<SelectMultiple>('filtro-situacao').value,
            NRLOCALCLIENTE: Metadata.getInstance<SelectMultiple>('filtro-local').value,
            NRSEQCONTRATO: Metadata.getInstance<SelectMultiple>('filtro-contratos').value,
            DTHORAGEND: Metadata.getInstance<DateRange>('data').value,
            TIPO: 3,
        }).finally(() => {
            this.fecharModalFiltros();
        });
    }

    public limparFiltros() {
        const iterable = Metadata.getInstance<IterableComponentRender>('iterable-cards-listagem-vistorias');

        Metadata.getInstance<SelectMultiple>('filtro-cliente').value = null;
        Metadata.getInstance<SelectMultiple>('filtro-operador').value = null;
        Metadata.getInstance<SelectMultiple>('filtro-situacao').value = null;
        Metadata.getInstance<SelectMultiple>('filtro-local').value = null;
        Metadata.getInstance<SelectMultiple>('filtro-contratos').value = null;
        Metadata.getInstance<DateRange>('data').value = null;

        this.carregarCardsVistorias({ component: iterable });
    }

    public async exibirModalInformacoes({ component }: any) {
        LoadingService.show();
        HttpCRUDTranslator.post('/getVistoriasListadas', {
            NRGERENCIAMENTOCHK: component.name.split('_')[1],
            TIPO: 2,
        }).then((response: IDictionary) => {
            const dados = response.data.data[0];

            this.vistoria = dados.NMGERENCIAMENTOCHK;
            this.contrato = (dados.NRCONTRATOFCT === null) ? 'Não há' : dados.NRCONTRATOFCT;
            this.cliente = dados.NMFANTCLIE;
            this.tarefa = dados.NMCHECKLISTAGEND;
            this.local = `${dados.NMLOCALCLIENTE} - ${dados.NMLOCALPAI}`;
            this.data = `${dados.DTAGEND} - ${dados.HORAAGEND}`;
            this.funcionario = dados.NMOPERADOR;
            this.supervisor = dados.SUPERVISOR;
            this.situacao = dados.SITUACAO;

            this.modalInformacoes.show();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public clickCard({ component }: any) {
        Router.replace(`/Detalhes_Vistoria/${component.name.split('_')[1]}/${component.name.split('_')[2]}`);
    }

    public carregarFotosVistoria({ component }: any) {
        const nr = this.nrGerenciamentoChk;
        const btnApagar = Metadata.getInstance<Button>('botao-apagar-imagens-vistoria');
        LoadingService.show();
        HttpCRUDTranslator.post('/getFotosVistorias', {
            NRGERENCIAMENTOCHK: nr,
        }).then((response: any) => {
            if (response.data.data.length === 0) {
                component.isVisible = false;
                Metadata.getInstance<Text>('sem-resultado-imagens-vistorias').isVisible = true;
                btnApagar.isVisible = false;
            } else {
                response.data.data.forEach((dados: IDictionary) => {
                    component.iterable.datasource.data.push({
                        NRFOTOTAREFAGERCHK: dados.NRFOTOTAREFAGERCHK,
                        DSFOTOTAREFAGERCHK: dados.DSFOTOTAREFAGERCHK,
                    });
                    btnApagar.isVisible = true;
                });
            }
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public async excluirFoto() {
        const carrosel = Metadata.getInstance<IterableCarousel>('carousel-imagens-anexo-vistorias');
        const img = carrosel.iterable.datasource.data;
        const [deleteData] = img.filter((value: any, index: any) => index === carrosel.currentSlide);

        LoadingService.show();
        HttpCRUDTranslator.post('/excluirFotoVistorias', {
            NRFOTOTAREFAGERCHK: deleteData.NRFOTOTAREFAGERCHK,
        }).then(() => {
            const data = img.filter((value: any, index: any) => index !== carrosel.currentSlide);
            carrosel.iterable.datasource.updateData(data);
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    // Funções da Tela de Detalhamento

    public exibirDetalhes({ component }: IEventParam<IterableComponentRender>) {
        this.visibilidadeTelaPrincipal = false;
        this.visibilidadeFrameDetalhes = !this.visibilidadeTelaPrincipal;

        setTimeout(() => {
            this.montarInformacoesComplementares(component.name.split('_')[1]);
        }, 500);
    }

    public ativaExibirDetalhes(NRGERENCIAMENTOCHK: any, NMLOCALCLIENTE: any) {
        const card = Metadata.getInstance<ZdCard>(`card-iteravel_${NRGERENCIAMENTOCHK}_${NMLOCALCLIENTE}`);
        card.click({} as Event);
    }

    public voltarTelaPrincipal() {
        this.visibilidadeTelaPrincipal = true;
        this.visibilidadeFrameDetalhes = !this.visibilidadeTelaPrincipal;
    }

    public montarInformacoesComplementares(nr: any) {
        const { data } = Metadata.getInstance<IterableComponentRender>('iterable-cards-listagem-vistorias').datasource;
        const cardAtividades = Metadata.getInstance<IterableComponentRender>('iterable-cards-itens-vistorias');
        const dados: any = data.find((row: any) => row.NRGERENCIAMENTOCHK === Number(nr));
        const observacao = Metadata.getInstance<Textarea>('textAreaObservation');

        this.tituloLocal = dados.NMLOCALCLIENTE;
        Metadata.getInstance<TextInput>('cod-tela').value = dados.NRGERENCIAMENTOCHK;
        Metadata.getInstance<Textarea>('textAreaObservation').value = (dados.OBS !== null) ? dados.OBS.replaceAll('_', '\n') : '';

        cardAtividades.datasource.setFilter({
            NRGERENCIAMENTOCHK: nr,
        });

        if (dados.IDOBRIGAOBSERVACAO !== 'S') {
            observacao.clearValidations();
        } else {
            observacao.addValidation('required', {});
        }

        this.bloquearAcoesVistoriaAvaliada(dados.IDSITUACAOGERCHK);
    }

    public bloquearAcoesVistoriaAvaliada(situacao: any) {
        if (situacao === '3') {
            this.disableCheckbox = true;
            this.disableVistoria = true;
            this.readonlyObservacao = true;
            this.disableSalvarVistoria = true;
            this.disableAnexarFoto = true;
        } else {
            this.disableCheckbox = false;
            this.disableVistoria = false;
            this.readonlyObservacao = false;
            this.disableSalvarVistoria = false;
            this.disableAnexarFoto = false;
        }
    }

    public montarCriterios({ component }: any) {
        HttpCRUDTranslator.post('/getCriterios', {
            NRATIVIDADECHK: component.name.split('_')[1],
            NRGERENCIAMENTOCHK: Metadata.getInstance<TextInput>('cod-tela').value,
        }).then((response: IDictionary) => {
            if (component.datasource instanceof SimpleDatasource) {
                component!.datasource!.items = response.data.map((elemento: any) => elemento.NMCRITERIOTARGERCHK);
                component.value = response.data.filter((elemento: any) => elemento.IDMARCADO === 'S').map((elemento: any) => elemento.NMCRITERIOTARGERCHK);
            }
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public salvarCriterios({ component }: any) {
        const iterableCards = Metadata.getInstance<IterableComponentRender>('iterable-cards-listagem-vistorias');
        HttpCRUDTranslator.post('/salvarCriterios', {
            CRITERIOS: Metadata.getInstance<CheckboxMultiple>(`checkbox-multiple_${component.name.split('_')[1]}`).value,
            NRATIVIDADECHK: component.name.split('_')[1],
            NRGERENCIAMENTOCHK: Metadata.getInstance<TextInput>('cod-tela').value,
        }).then(() => {
            Utilities.showSuccessMessage();
            iterableCards.datasource.get();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public finalizarVistoria() {
        const form = Metadata.getInstance<Form>('form-observacoes');
        const iterableVistorias = Metadata.getInstance<IterableComponentRender>('iterable-cards-listagem-vistorias');
        const { data } = Metadata.getInstance<IterableComponentRender>('iterable-cards-itens-vistorias').datasource;
        const atividades = data.map((elemento: any) => elemento.NRATIVIDADECHK);
        const textArea = Metadata.getInstance<Textarea>('textAreaObservation');
        let contador = 0;
        let obs = '';

        LoadingService.show();
        atividades.forEach((nr: any) => {
            const criterio = Metadata.getInstance<CheckboxMultiple>(`checkbox-multiple_${nr}`).value;

            if (criterio.length > 0) {
                contador += 1;
                obs = textArea.value;
            } else if (contador === 0) {
                obs = (textArea.value) ? `${textArea.value}__Mensagem automática: Vistoria finalizada sem critérios de não conformidade` : 'Mensagem automática: Vistoria finalizada sem critérios de não conformidade';
            }
        });

        if (Utilities.validateForm(form)) {
            HttpCRUDTranslator.post('/finalizarVistoria', {
                NRGERENCIAMENTOCHK: Metadata.getInstance<TextInput>('cod-tela').value,
                DSOBSTAREFAGERCHK: obs,
                ATIVIDADES: atividades,
                POSSUINAOCONFORM: contador > 0,
            }).then(() => {
                Utilities.showSuccessMessage();
                iterableVistorias.datasource.get();
                this.visibilidadeFrameDetalhes = false;
                this.visibilidadeTelaPrincipal = true;
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public exibirImagemAnexada({ component }: any) {
        const { datasource } = Metadata.getInstance<IterableCarousel>('carousel-imagens').iterable;
        const imagens: any = [];

        if (component.value.length) {
            this.visibilidadeCarroselImagens = true;
            component.value.forEach((elemento: any, posicao: any) => {
                imagens.push({
                    id: posicao,
                    src: window.URL.createObjectURL(elemento),
                });
            });
        } else {
            this.visibilidadeCarroselImagens = false;
        }
        datasource.updateData(imagens);
    }

    public async anexarImagens() {
        const imagensConvertidas = await FileUpload.converterImagens('file-input-anexar-imagem');
        const fileInput = Metadata.getInstance<FileInput>('file-input-anexar-imagem');
        const iterableVistorias = Metadata.getInstance<IterableComponentRender>('iterable-cards-listagem-vistorias');

        if (fileInput.value) {
            LoadingService.show();
            HttpCRUDTranslator.post('/anexarImagensVistoria', {
                IMAGENS: imagensConvertidas,
                NRGERENCIAMENTOCHK: Metadata.getInstance<TextInput>('cod-tela').value,
            }).then(() => {
                Utilities.showSuccessMessage();
                this.fecharModalAnexar();
                iterableVistorias.datasource.get();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        } else {
            Utilities.alertMessage('Nenhuma imagem foi anexada', 'error');
        }
    }

    public stylizeStatus({ component }: IEventParam<Text>) {
        if (component.text === 'Aguardando Vistoria') {
            component.text = "<span  style='background-color:#dee2e6; color: #ff6700; font-size: 12px;'>AGUARDANDO VISTORIA</span>";
        }
        if (component.text === 'Avaliado') {
            component.text = "<span  style='background-color: #dee2e6; color: #2b9348; font-size: 12px;'>A V A L I A D O</span>";
        }
        if (component.text === 'Em andamento') {
            component.text = "<span  style='background-color: #dee2e6; color: #023e8a; font-size: 12px;'>EM ANDAMENTO</span>";
        }
        if (component.text === 'Cancelado') {
            component.text = "<span  style='background-color:#dee2e6; color: black; font-size: 12px;'>C A N C E L A D O</span>";
        }
        if (component.text === 'Tarefa Pendente') {
            component.text = "<span  style='background-color:#dee2e6; color: #ff6700; font-size: 12px;'>TAREFA PENDENTE</span>";
        }
        if (component.text === 'Pendente') {
            component.text = "<span  style='background-color:#dee2e6; color: #ff6700; font-size: 12px;'>P E N D E N T E</span>";
        }
    }

    public carregarCardsAprovacoes({ component }: any) {
        component.datasource.setFilter({
            FILTRO: false,
        });
        component.datasource.get();
    }

    public aprovarReport({ component }: any) {
        const iterableAprovacoes = Metadata.getInstance<IterableComponentRender>('iterable-cards-listagem-aprovacoes');
        const nrChkAgend = component.name.split('_')[1];
        LoadingService.show();
        Http.post('/aprovarReport', {
            NRCHECKLISTAGEND: nrChkAgend,
            NMCHECKLISTAGEND: Metadata.getInstance<Text>(`nome-tarefa_${nrChkAgend}`).text,
            NRGERENCIAMENTOCHK: Metadata.getInstance<TextInput>(`NRGERENCIAMENTOCHK_${nrChkAgend}`).value,
            NMGERENCIAMENTOCHK: Metadata.getInstance<Text>(`NMGERENCIAMENTOCHK_${nrChkAgend}`).text,
            DSJUSTCANCELAMENTO: Metadata.getInstance<Text>(`DSJUSTCANCELAMENTO_${nrChkAgend}`).text,
        }).then(() => {
            Utilities.showSuccessMessage();
            iterableAprovacoes.datasource.get();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    /* eslint-disable */
    public recusarReport({ component }: any) {
        this.nrChkAgendRecusar = component.name.split('_')[1];
        this.abrirModalRecusarReport();
    }
    /* eslint-enable */

    public async disabledOperadorTarefa() {
        const data = Metadata.getInstance<Date>('input-data-tarefa');
        const horario = Metadata.getInstance<Time>('input-horario-tarefa');
        const duracao = Metadata.getInstance<TextInput>('input-duracao-tarefa');
        const selectOperador = Metadata.getInstance<Select>('select-operador-tarefa');

        if (data.value == null || horario.value == null || duracao.value == null) {
            selectOperador.disabled = true;
        } else {
            const operadores = await this.getOperadoresFiltrados(data.value, horario.value, duracao.value);
            selectOperador.disabled = false;
            selectOperador.datasource.setFilter({
                CDOPERADOR: operadores,
            });
        }
    }

    public async getOperadoresFiltrados(data: any, horaInicio: any, duracao: any) {
        let operadoresFiltrados: any[] = [];
        await Http.get('/getOperadoresFiltrados', {
            params: {
                DATA: data,
                HORAINICIO: horaInicio,
                DURACAO: duracao,
                NRLOCALCLIENTE: Metadata.getInstance<TextInput>(`NRLOCALCLIENTE_${this.nrChkAgendRecusar}`).value,
            },
        }).then((response) => {
            operadoresFiltrados = response.data.data.map((obj: any) => obj.CDOPERADOR);
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        });

        return operadoresFiltrados;
    }

    public salvarVoltaTarefa() {
        const form = Metadata.getInstance<Form>('form-recusar-report');

        if (Utilities.validateForm(form)) {
            // const gridAprovacoes = Metadata.getInstance<TekGrid>('grid-aprovacoes');
            const data = Metadata.getInstance<Date>('input-data-tarefa');
            const horario = Metadata.getInstance<Time>('input-horario-tarefa');
            const duracao = Metadata.getInstance<TextInput>('input-duracao-tarefa');
            const selectOperador = Metadata.getInstance<Select>('select-operador-tarefa');
            const iterableAprovacoes = Metadata.getInstance<IterableComponentRender>('iterable-cards-listagem-aprovacoes');

            LoadingService.show();
            Http.post('/voltarTarefaReportada', {
                NRCHECKLISTAGEND: this.nrChkAgendRecusar,
                NMCHECKLISTAGEND: Metadata.getInstance<Text>(`nome-tarefa_${this.nrChkAgendRecusar}`).text,
                NRGERENCIAMENTOCHK: Metadata.getInstance<TextInput>(`NRGERENCIAMENTOCHK_${this.nrChkAgendRecusar}`).value,
                NMGERENCIAMENTOCHK: Metadata.getInstance<Text>(`NMGERENCIAMENTOCHK_${this.nrChkAgendRecusar}`).text,
                DATA: data.value,
                HORAINICIO: horario.value,
                DURACAO: duracao.value,
                CDOPERADOR: selectOperador.value,
            }).then(() => {
                Utilities.showSuccessMessage();
                this.fecharModalRecusarReport();
                iterableAprovacoes.datasource.get();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public exibirModalDadosAprovacao({ component }: any) {
        const nrChkAgend = component.name.split('_')[1];
        const nrSeqContrato = Metadata.getInstance<TextInput>(`NRSEQCONTRATO_${nrChkAgend}`).value;

        this.vistoria = Metadata.getInstance<Text>(`NMGERENCIAMENTOCHK_${nrChkAgend}`).text;
        this.contrato = (nrSeqContrato === null) ? 'Não há' : nrSeqContrato;
        this.cliente = Metadata.getInstance<Text>(`NMRAZSOCCLIE_${nrChkAgend}`).text;
        this.tarefa = Metadata.getInstance<Text>(`nome-tarefa_${nrChkAgend}`).text;
        this.local = Metadata.getInstance<Text>(`local_${nrChkAgend}`).text;
        this.data = `${Metadata.getInstance<Text>(`DTAGEND_${nrChkAgend}`).text} - ${Metadata.getInstance<Text>(`HORAAGEND_${nrChkAgend}`).text}`;
        this.funcionario = Metadata.getInstance<Text>(`NMOPERRESPONSAVEL_${nrChkAgend}`).text;
        this.supervisor = Metadata.getInstance<Text>(`NMOPERADOR_${nrChkAgend}`).text;
        this.situacao = Metadata.getInstance<Text>(`DSJUSTCANCELAMENTO_${nrChkAgend}`).text;

        this.abrirModalDadosAprovacao();
    }

    /* eslint-disable */
    public exibirModalImagensAprovacao({ component }: any) {
        this.nrChkAgendImagem = component.name.split('_')[1];
        this.abrirModalImagensAprovacao();
    }
    /* eslint-enable */

    public carregarFotosAprovacao({ component }: any) {
        component.iterable.datasource.updateData([]);
        const nr = this.nrChkAgendImagem;
        LoadingService.show();
        Http.post('/getFotosAprovacao', {
            NRCHECKLISTAGEND: nr,
        }).then((response: any) => {
            if (response.data.data.length === 0) {
                component.isVisible = false;
                Metadata.getInstance<Text>('sem-resultado-imagens-aprovacao').isVisible = true;
            } else {
                response.data.data.forEach((dados: IDictionary) => {
                    component.iterable.datasource.data.push({
                        NRFOTOTAREFAAGEND: dados.NRFOTOTAREFAAGEND,
                        DSFOTOTAREFAAGEND: dados.DSFOTOTAREFAAGEND,
                    });
                });
            }
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public filtrarCardsAprovacoes() {
        const iterable = Metadata.getInstance<IterableComponentRender>('iterable-cards-listagem-aprovacoes');

        iterable.datasource.setFilter({
            CDCLIENTE: Metadata.getInstance<SelectMultiple>('filtro-cliente-aprovacoes').value,
            CDOPERADOR: Metadata.getInstance<SelectMultiple>('filtro-operador-aprovacoes').value,
            NRLOCALCLIENTE: Metadata.getInstance<SelectMultiple>('filtro-local-aprovacoes').value,
            NRSEQCONTRATO: Metadata.getInstance<SelectMultiple>('filtro-contratos-aprovacoes').value,
            DTHORAGEND: Metadata.getInstance<DateRange>('data-aprovacoes').value,
            FILTRO: true,
        }).finally(() => {
            this.fecharModalFiltrarAprovacoes();
        });
    }

    public limparFiltrosAprovacoes() {
        const iterable = Metadata.getInstance<IterableComponentRender>('iterable-cards-listagem-vistorias');

        Metadata.getInstance<SelectMultiple>('filtro-cliente-aprovacoes').value = null;
        Metadata.getInstance<SelectMultiple>('filtro-operador-aprovacoes').value = null;
        Metadata.getInstance<SelectMultiple>('filtro-local-aprovacoes').value = null;
        Metadata.getInstance<SelectMultiple>('filtro-contratos-aprovacoes').value = null;
        Metadata.getInstance<DateRange>('data-aprovacoes').value = null;

        this.carregarCardsAprovacoes({ component: iterable });
    }

    public ordenarCardsAprovacoes({ component }: IEventParam<Button>) {
        const iterable = Metadata.getInstance<TekIterableComponentRender>('iterable-cards-listagem-aprovacoes');

        iterable.datasource.clearOrder();
        if (component.name === 'botao-ordenar-vistoria') {
            iterable.datasource.addOrder('NMCHECKLISTAGEND', 'ASC');
        } else if (component.name === 'botao-ordenar-local') {
            iterable.datasource.addOrder('NMLOCALCLIENTE', 'ASC');
        } else if (component.name === 'botao-ordenar-data') {
            iterable.datasource.addOrder('DTHORAAGEND', 'DESC');
        } else {
            iterable.datasource.clearOrder();
        }

        const { order } = iterable.datasource;
        if (order) {
            const campo = (order.length === 0) ? '' : order[0].split('.')[0];
            this.exibirTipoOrdenacaoAprovacoes(campo);
        }

        iterable.datasource.setPage(1);
    }

    public exibirTipoOrdenacaoAprovacoes(name: any) {
        const visibilidadeText = Metadata.getInstance<Text>('titulo-ordenacao-aprovacoes');

        switch (name) {
            case 'NMGERENCIAMENTOCHK':
                this.tipoOrdenacaoAprovacoes = 'Ordenado por nome da Tarefa';
                visibilidadeText.isVisible = true;
                break;
            case 'NMLOCALCLIENTE':
                this.tipoOrdenacaoAprovacoes = 'Ordenado por Local';
                visibilidadeText.isVisible = true;
                break;
            case 'DATACOMPLETA':
                this.tipoOrdenacaoAprovacoes = 'Ordenado por Data';
                visibilidadeText.isVisible = true;
                break;
            default:
                this.tipoOrdenacaoAprovacoes = '';
                visibilidadeText.isVisible = false;
                break;
        }
    }
}
